@@ -4,8 +4,8 @@
   op.rdfp <- list(
     rdfp.network_code = NULL,
     rdfp.application_name = "DFP API from R",
-    rdfp.httr_oauth_cache = TRUE,
-    rdfp.version = 'v201802',
+    rdfp.httr_oauth_cache = ".httr-oauth-rdfp",
+    rdfp.version = 'v201811',
     rdfp.client_id = "1017468132430-k0h1fmcnqvuf3tt62si7c574sridq32b.apps.googleusercontent.com",
     rdfp.client_secret = "dzFYtzTPbkcF90GhUOqTgIM-",
     rdfp.webapp.client_id = "1017468132430-mtbatv3buou1tq4q6oj79tsb76l14c6c.apps.googleusercontent.com",
