@@ -1,100 +1,100 @@
 service_map <- list(
-# deprecated
-#   'v201405'=
-#     c('ActivityGroupService', 'ActivityService', 'AdRuleService',
-#      'AudienceSegmentService', 'BaseRateService', 'CompanyService',
-#      'ContactService', 'ContentBundleService',
-#      'ContentMetadataKeyHierarchyService', 'ContentService',
-#      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
-#      'CreativeWrapperService', 'CustomFieldService',
-#      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
-#      'InventoryService', 'LabelService',
-#      'LineItemCreativeAssociationService', 'LineItemService',
-#      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
-#      'OrderService', 'PlacementService', 'ProductService',
-#      'ProductTemplateService', 'ProposalLineItemService', 'ProposalService',
-#      'PublisherQueryLanguageService', 'RateCardCustomizationService',
-#      'RateCardCustomizationGroupService', 'RateCardService',
-#      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
-#      'ReconciliationReportService', 'ReportService',
-#      'SuggestedAdUnitService', 'TeamService', 'UserService',
-#      'UserTeamAssociationService', 'WorkflowRequestService'),
-#   'v201408'=
-#     c('ActivityGroupService', 'ActivityService', 'AdRuleService',
-#      'AudienceSegmentService', 'BaseRateService', 'CompanyService',
-#      'ContactService', 'ContentBundleService',
-#      'ContentMetadataKeyHierarchyService', 'ContentService',
-#      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
-#      'CreativeWrapperService', 'CustomFieldService',
-#      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
-#      'InventoryService', 'LabelService',
-#      'LineItemCreativeAssociationService', 'LineItemService',
-#      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
-#      'OrderService', 'PlacementService', 'PremiumRateService',
-#      'ProductService', 'ProductTemplateService', 'ProposalLineItemService',
-#      'ProposalService', 'PublisherQueryLanguageService', 'RateCardService',
-#      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
-#      'ReconciliationReportService', 'ReportService',
-#      'SuggestedAdUnitService', 'TeamService', 'UserService',
-#      'UserTeamAssociationService', 'WorkflowRequestService'),
-#   'v201411'=
-#     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
-#      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
-#      'CompanyService', 'ContactService', 'ContentBundleService',
-#      'ContentMetadataKeyHierarchyService', 'ContentService',
-#      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
-#      'CreativeWrapperService', 'CustomFieldService',
-#      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
-#      'InventoryService', 'LabelService',
-#      'LineItemCreativeAssociationService', 'LineItemService',
-#      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
-#      'OrderService', 'PlacementService', 'PremiumRateService',
-#      'ProductService', 'ProductTemplateService', 'ProposalLineItemService',
-#      'ProposalService', 'PublisherQueryLanguageService', 'RateCardService',
-#      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
-#      'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
-#      'SuggestedAdUnitService', 'TeamService', 'UserService',
-#      'UserTeamAssociationService', 'WorkflowRequestService'),
-#   'v201502'=
-#     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
-#      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
-#      'CompanyService', 'ContactService', 'ContentBundleService',
-#      'ContentMetadataKeyHierarchyService', 'ContentService',
-#      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
-#      'CreativeWrapperService', 'CustomFieldService',
-#      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
-#      'InventoryService', 'LabelService',
-#      'LineItemCreativeAssociationService', 'LineItemService',
-#      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
-#      'OrderService', 'PackageService', 'PlacementService',
-#      'PremiumRateService', 'ProductService', 'ProductPackageService',
-#      'ProductPackageItemService', 'ProductTemplateService',
-#      'ProposalLineItemService', 'ProposalService',
-#      'PublisherQueryLanguageService', 'RateCardService',
-#      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
-#      'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
-#      'SuggestedAdUnitService', 'TeamService', 'UserService',
-#      'UserTeamAssociationService', 'WorkflowRequestService'),
-#   'v201505'=
-#     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
-#      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
-#      'CompanyService', 'ContactService', 'ContentBundleService',
-#      'ContentMetadataKeyHierarchyService', 'ContentService',
-#      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
-#      'CreativeWrapperService', 'CustomFieldService',
-#      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
-#      'InventoryService', 'LabelService',
-#      'LineItemCreativeAssociationService', 'LineItemService',
-#      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
-#      'OrderService', 'PackageService', 'PlacementService',
-#      'PremiumRateService', 'ProductService', 'ProductPackageService',
-#      'ProductPackageItemService', 'ProductTemplateService',
-#      'ProposalLineItemService', 'ProposalService',
-#      'PublisherQueryLanguageService', 'RateCardService',
-#      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
-#      'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
-#      'SuggestedAdUnitService', 'TeamService', 'UserService',
-#      'UserTeamAssociationService', 'WorkflowRequestService'),
+  # deprecated
+  #   'v201405'=
+  #     c('ActivityGroupService', 'ActivityService', 'AdRuleService',
+  #      'AudienceSegmentService', 'BaseRateService', 'CompanyService',
+  #      'ContactService', 'ContentBundleService',
+  #      'ContentMetadataKeyHierarchyService', 'ContentService',
+  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
+  #      'CreativeWrapperService', 'CustomFieldService',
+  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
+  #      'InventoryService', 'LabelService',
+  #      'LineItemCreativeAssociationService', 'LineItemService',
+  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
+  #      'OrderService', 'PlacementService', 'ProductService',
+  #      'ProductTemplateService', 'ProposalLineItemService', 'ProposalService',
+  #      'PublisherQueryLanguageService', 'RateCardCustomizationService',
+  #      'RateCardCustomizationGroupService', 'RateCardService',
+  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+  #      'ReconciliationReportService', 'ReportService',
+  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
+  #      'UserTeamAssociationService', 'WorkflowRequestService'),
+  #   'v201408'=
+  #     c('ActivityGroupService', 'ActivityService', 'AdRuleService',
+  #      'AudienceSegmentService', 'BaseRateService', 'CompanyService',
+  #      'ContactService', 'ContentBundleService',
+  #      'ContentMetadataKeyHierarchyService', 'ContentService',
+  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
+  #      'CreativeWrapperService', 'CustomFieldService',
+  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
+  #      'InventoryService', 'LabelService',
+  #      'LineItemCreativeAssociationService', 'LineItemService',
+  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
+  #      'OrderService', 'PlacementService', 'PremiumRateService',
+  #      'ProductService', 'ProductTemplateService', 'ProposalLineItemService',
+  #      'ProposalService', 'PublisherQueryLanguageService', 'RateCardService',
+  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+  #      'ReconciliationReportService', 'ReportService',
+  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
+  #      'UserTeamAssociationService', 'WorkflowRequestService'),
+  #   'v201411'=
+  #     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
+  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
+  #      'CompanyService', 'ContactService', 'ContentBundleService',
+  #      'ContentMetadataKeyHierarchyService', 'ContentService',
+  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
+  #      'CreativeWrapperService', 'CustomFieldService',
+  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
+  #      'InventoryService', 'LabelService',
+  #      'LineItemCreativeAssociationService', 'LineItemService',
+  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
+  #      'OrderService', 'PlacementService', 'PremiumRateService',
+  #      'ProductService', 'ProductTemplateService', 'ProposalLineItemService',
+  #      'ProposalService', 'PublisherQueryLanguageService', 'RateCardService',
+  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+  #      'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
+  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
+  #      'UserTeamAssociationService', 'WorkflowRequestService'),
+  #   'v201502'=
+  #     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
+  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
+  #      'CompanyService', 'ContactService', 'ContentBundleService',
+  #      'ContentMetadataKeyHierarchyService', 'ContentService',
+  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
+  #      'CreativeWrapperService', 'CustomFieldService',
+  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
+  #      'InventoryService', 'LabelService',
+  #      'LineItemCreativeAssociationService', 'LineItemService',
+  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
+  #      'OrderService', 'PackageService', 'PlacementService',
+  #      'PremiumRateService', 'ProductService', 'ProductPackageService',
+  #      'ProductPackageItemService', 'ProductTemplateService',
+  #      'ProposalLineItemService', 'ProposalService',
+  #      'PublisherQueryLanguageService', 'RateCardService',
+  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+  #      'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
+  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
+  #      'UserTeamAssociationService', 'WorkflowRequestService'),
+  #   'v201505'=
+  #     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
+  #      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
+  #      'CompanyService', 'ContactService', 'ContentBundleService',
+  #      'ContentMetadataKeyHierarchyService', 'ContentService',
+  #      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
+  #      'CreativeWrapperService', 'CustomFieldService',
+  #      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
+  #      'InventoryService', 'LabelService',
+  #      'LineItemCreativeAssociationService', 'LineItemService',
+  #      'LineItemTemplateService', 'LiveStreamEventService', 'NetworkService',
+  #      'OrderService', 'PackageService', 'PlacementService',
+  #      'PremiumRateService', 'ProductService', 'ProductPackageService',
+  #      'ProductPackageItemService', 'ProductTemplateService',
+  #      'ProposalLineItemService', 'ProposalService',
+  #      'PublisherQueryLanguageService', 'RateCardService',
+  #      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+  #      'ReconciliationReportService', 'ReportService', 'SharedAdUnitService',
+  #      'SuggestedAdUnitService', 'TeamService', 'UserService',
+  #      'UserTeamAssociationService', 'WorkflowRequestService'),
   # 'v201508'=
   #   c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
   #    'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
@@ -245,70 +245,70 @@ service_map <- list(
   #      'UserTeamAssociationService', 'WorkflowRequestService'),
   'v201705'=
     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
-     'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
-     'CompanyService', 'ContactService', 'ContentBundleService',
-     'ContentMetadataKeyHierarchyService', 'ContentService',
-     'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
-     'CreativeWrapperService', 'CustomFieldService',
-     'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
-     'InventoryService', 'LabelService',
-     'LineItemCreativeAssociationService', 'LineItemService',
-     'LineItemTemplateService', 'LiveStreamEventService',
-     'MobileApplicationService', 'NativeStyleService', 'NetworkService',
-     'OrderService', 'PackageService', 'PlacementService',
-     'PremiumRateService', 'ProductService', 'ProductPackageService',
-     'ProductPackageItemService', 'ProductTemplateService',
-     'ProposalLineItemService', 'ProposalService',
-     'PublisherQueryLanguageService', 'RateCardService',
-     'ReconciliationOrderReportService', 'ReconciliationReportRowService',
-     'ReconciliationLineItemReportService',
-     'ReconciliationReportService', 'ReportService',
-     'SuggestedAdUnitService', 'TeamService', 'UserService',
-     'UserTeamAssociationService', 'WorkflowRequestService'),
+      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
+      'CompanyService', 'ContactService', 'ContentBundleService',
+      'ContentMetadataKeyHierarchyService', 'ContentService',
+      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
+      'CreativeWrapperService', 'CustomFieldService',
+      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
+      'InventoryService', 'LabelService',
+      'LineItemCreativeAssociationService', 'LineItemService',
+      'LineItemTemplateService', 'LiveStreamEventService',
+      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
+      'OrderService', 'PackageService', 'PlacementService',
+      'PremiumRateService', 'ProductService', 'ProductPackageService',
+      'ProductPackageItemService', 'ProductTemplateService',
+      'ProposalLineItemService', 'ProposalService',
+      'PublisherQueryLanguageService', 'RateCardService',
+      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+      'ReconciliationLineItemReportService',
+      'ReconciliationReportService', 'ReportService',
+      'SuggestedAdUnitService', 'TeamService', 'UserService',
+      'UserTeamAssociationService', 'WorkflowRequestService'),
   'v201708'=
     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
-     'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
-     'CompanyService', 'ContactService', 'ContentBundleService',
-     'ContentMetadataKeyHierarchyService', 'ContentService',
-     'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
-     'CreativeWrapperService', 'CustomFieldService',
-     'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
-     'InventoryService', 'LabelService',
-     'LineItemCreativeAssociationService', 'LineItemService',
-     'LineItemTemplateService', 'LiveStreamEventService',
-     'MobileApplicationService', 'NativeStyleService', 'NetworkService',
-     'OrderService', 'PackageService', 'PlacementService',
-     'PremiumRateService', 'ProductService', 'ProductPackageService',
-     'ProductPackageItemService', 'ProductTemplateService',
-     'ProposalLineItemService', 'ProposalService',
-     'PublisherQueryLanguageService', 'RateCardService',
-     'ReconciliationOrderReportService', 'ReconciliationReportRowService',
-     'ReconciliationLineItemReportService',
-     'ReconciliationReportService', 'ReportService',
-     'SuggestedAdUnitService', 'TeamService', 'UserService',
-     'UserTeamAssociationService', 'WorkflowRequestService'),
+      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
+      'CompanyService', 'ContactService', 'ContentBundleService',
+      'ContentMetadataKeyHierarchyService', 'ContentService',
+      'CreativeService', 'CreativeSetService', 'CreativeTemplateService',
+      'CreativeWrapperService', 'CustomFieldService',
+      'CustomTargetingService', 'ExchangeRateService', 'ForecastService',
+      'InventoryService', 'LabelService',
+      'LineItemCreativeAssociationService', 'LineItemService',
+      'LineItemTemplateService', 'LiveStreamEventService',
+      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
+      'OrderService', 'PackageService', 'PlacementService',
+      'PremiumRateService', 'ProductService', 'ProductPackageService',
+      'ProductPackageItemService', 'ProductTemplateService',
+      'ProposalLineItemService', 'ProposalService',
+      'PublisherQueryLanguageService', 'RateCardService',
+      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+      'ReconciliationLineItemReportService',
+      'ReconciliationReportService', 'ReportService',
+      'SuggestedAdUnitService', 'TeamService', 'UserService',
+      'UserTeamAssociationService', 'WorkflowRequestService'),
   'v201711'=
     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
-     'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
-     'CdnConfigurationService', 'CompanyService', 'ContactService',
-     'ContentBundleService', 'ContentMetadataKeyHierarchyService',
-     'ContentService', 'CreativeService', 'CreativeSetService',
-     'CreativeTemplateService', 'CreativeWrapperService',
-     'CustomFieldService', 'CustomTargetingService', 'ExchangeRateService',
-     'ForecastService', 'InventoryService', 'LabelService',
-     'LineItemCreativeAssociationService', 'LineItemService',
-     'LineItemTemplateService', 'LiveStreamEventService',
-     'MobileApplicationService', 'NativeStyleService', 'NetworkService',
-     'OrderService', 'PackageService', 'PlacementService',
-     'PremiumRateService', 'ProductService', 'ProductPackageService',
-     'ProductPackageItemService', 'ProductTemplateService',
-     'ProposalLineItemService', 'ProposalService',
-     'PublisherQueryLanguageService', 'RateCardService',
-     'ReconciliationOrderReportService', 'ReconciliationReportRowService',
-     'ReconciliationLineItemReportService',
-     'ReconciliationReportService', 'ReportService',
-     'SuggestedAdUnitService', 'TeamService', 'UserService',
-     'UserTeamAssociationService', 'WorkflowRequestService'),
+      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
+      'CdnConfigurationService', 'CompanyService', 'ContactService',
+      'ContentBundleService', 'ContentMetadataKeyHierarchyService',
+      'ContentService', 'CreativeService', 'CreativeSetService',
+      'CreativeTemplateService', 'CreativeWrapperService',
+      'CustomFieldService', 'CustomTargetingService', 'ExchangeRateService',
+      'ForecastService', 'InventoryService', 'LabelService',
+      'LineItemCreativeAssociationService', 'LineItemService',
+      'LineItemTemplateService', 'LiveStreamEventService',
+      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
+      'OrderService', 'PackageService', 'PlacementService',
+      'PremiumRateService', 'ProductService', 'ProductPackageService',
+      'ProductPackageItemService', 'ProductTemplateService',
+      'ProposalLineItemService', 'ProposalService',
+      'PublisherQueryLanguageService', 'RateCardService',
+      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+      'ReconciliationLineItemReportService',
+      'ReconciliationReportService', 'ReportService',
+      'SuggestedAdUnitService', 'TeamService', 'UserService',
+      'UserTeamAssociationService', 'WorkflowRequestService'),
   'v201802'=
     c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
       'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
@@ -330,5 +330,73 @@ service_map <- list(
       'ReconciliationLineItemReportService',
       'ReconciliationReportService', 'ReportService',
       'SuggestedAdUnitService', 'TeamService', 'UserService',
+      'UserTeamAssociationService', 'WorkflowRequestService'),
+  'v201805'=
+    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
+      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
+      'CdnConfigurationService', 'CompanyService', 'ContactService',
+      'ContentBundleService', 'ContentMetadataKeyHierarchyService',
+      'ContentService', 'CreativeService', 'CreativeSetService',
+      'CreativeTemplateService', 'CreativeWrapperService',
+      'CustomFieldService', 'CustomTargetingService',
+      'DaiAuthenticationKeyService', 'ExchangeRateService',
+      'ForecastService', 'InventoryService', 'LabelService',
+      'LineItemCreativeAssociationService', 'LineItemService',
+      'LineItemTemplateService', 'LiveStreamEventService',
+      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
+      'OrderService', 'PackageService', 'PlacementService',
+      'PremiumRateService', 'ProductService', 'ProductPackageService',
+      'ProductPackageItemService', 'ProductTemplateService',
+      'ProposalLineItemService', 'ProposalService',
+      'PublisherQueryLanguageService', 'RateCardService',
+      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+      'ReconciliationLineItemReportService',
+      'ReconciliationReportService', 'ReportService',
+      'SuggestedAdUnitService', 'TeamService', 'UserService',
+      'UserTeamAssociationService', 'WorkflowRequestService'),
+  'v201808'=
+    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
+      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
+      'CdnConfigurationService', 'CompanyService', 'ContactService',
+      'ContentBundleService', 'ContentMetadataKeyHierarchyService',
+      'ContentService', 'CreativeService', 'CreativeSetService',
+      'CreativeTemplateService', 'CreativeWrapperService',
+      'CustomFieldService', 'CustomTargetingService',
+      'DaiAuthenticationKeyService', 'ExchangeRateService',
+      'ForecastService', 'InventoryService', 'LabelService',
+      'LineItemCreativeAssociationService', 'LineItemService',
+      'LineItemTemplateService', 'LiveStreamEventService',
+      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
+      'OrderService', 'PackageService', 'PlacementService',
+      'PremiumRateService', 'ProductService', 'ProductPackageService',
+      'ProductPackageItemService', 'ProductTemplateService',
+      'ProposalLineItemService', 'ProposalService',
+      'PublisherQueryLanguageService', 'RateCardService',
+      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+      'ReconciliationLineItemReportService',
+      'ReconciliationReportService', 'ReportService',
+      'SuggestedAdUnitService', 'TeamService', 'UserService',
+      'UserTeamAssociationService', 'WorkflowRequestService'),
+  'v201811'=
+    c('ActivityGroupService', 'ActivityService', 'AdExclusionRuleService',
+      'AdRuleService', 'AudienceSegmentService', 'BaseRateService',
+      'CdnConfigurationService', 'CompanyService', 'ContactService',
+      'ContentBundleService', 'ContentService', 'CreativeService',
+      'CreativeSetService', 'CreativeTemplateService',
+      'CreativeWrapperService', 'CustomFieldService',
+      'CustomTargetingService', 'DaiAuthenticationKeyService',
+      'ExchangeRateService', 'ForecastService', 'InventoryService',
+      'LabelService', 'LineItemCreativeAssociationService',
+      'LineItemService', 'LineItemTemplateService', 'LiveStreamEventService',
+      'MobileApplicationService', 'NativeStyleService', 'NetworkService',
+      'OrderService', 'PackageService', 'PlacementService',
+      'PremiumRateService', 'ProductService', 'ProductPackageService',
+      'ProductPackageItemService', 'ProductTemplateService',
+      'ProposalLineItemService', 'ProposalService',
+      'PublisherQueryLanguageService', 'RateCardService',
+      'ReconciliationOrderReportService', 'ReconciliationReportRowService',
+      'ReconciliationLineItemReportService',
+      'ReconciliationReportService', 'ReportService',
+      'SuggestedAdUnitService', 'TeamService', 'UserService',
       'UserTeamAssociationService', 'WorkflowRequestService')
 )
